#
# spec file for package coolkey
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           coolkey
Version:        1.1.0
Release:        154.1
Summary:        CoolKey and CAC PKCS #11 PKI Module for Smart Cards
License:        LGPL-2.1
Group:          Productivity/Security
Url:            http://directory.fedoraproject.org/wiki/CoolKey
Source:         %{name}-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
# Patches imported from Fedora:
# PATCH-FIX-FEDORA coolkey-gcc43.patch bnc661643 sbrabec@suse.cz -- Fix for gcc-4.3.
Patch2:         coolkey-gcc43.patch
# PATCH-FEATURE-FEDORA coolkey-latest.patch bnc661643 sbrabec@suse.cz -- The head branch patch.
Patch3:         coolkey-latest.patch
# PATCH-FIX-FEDORA coolkey-simple-bugs.patch bnc661643 sbrabec@suse.cz -- Fix imported from Fedora, mostly merging former SUSE fixes.
Patch4:         coolkey-simple-bugs.patch
# PATCH-FIX-FEDORA coolkey-thread-fix.patch bnc661643 sbrabec@suse.cz -- Fix threading.
Patch5:         coolkey-thread-fix.patch
# PATCH-FEATURE-FEDORA coolkey-cac.patch bnc661643 sbrabec@suse.cz -- Support for CAC cards.
Patch6:         coolkey-cac.patch
# PATCH-FIX-FEDORA coolkey-cac-1.patch bnc661643 sbrabec@suse.cz -- Fixes of CAC support patch.
Patch7:         coolkey-cac-1.patch
# PATCH-FIX-FEDORA coolkey-pcsc-lite-fix.patch bnc661643 sbrabec@suse.cz -- Port to the latest pcsc-lite.
Patch8:         coolkey-pcsc-lite-fix.patch
# SUSE specific patches:
# PATCH-FEATURE-SLES coolkey-1.1.0-evoandooo.patch jberkman@novell.com -- Teach pk11install about evolution and openoffice.
Patch53:        coolkey-1.1.0-evoandooo.patch
# PATCH-FIX-SECURITY coolkey-cache-dir-move.patch sbrabec@suse.cz bnc304180 CVE-2007-4129 -- Fix file and directory permission flaw.
Patch54:        coolkey-cache-dir-move.patch
# PATCH-FIX-UPSTREAM coolkey-null.patch redhat356971 sbrabec@suse.cz -- Fix invalid NULL declaration.
Patch55:        coolkey-null.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++ mozilla-nss-devel pcsc-lite-devel pkg-config zlib-devel
BuildRequires:  libtool
#Requires:       pcsc-lite
# Requires: ifd-egate
Requires:       pcsc-ccid
# 390 does not have libusb or smartCards
ExcludeArch:    s390 s390x

%description
Linux Driver support for the CoolKey and CAC products. CoolKeys are
part of a complete PKI solution that provides smart card login, single
sign-on, secure messaging, and secure email access. In the complete
solution, users are issued CoolKeys by their employer, ISP, bank, or
other parties. When the user plugs the keys in for the first time, the
keys are automatically provisioned with certificates, keys, and a PIN,
unique for that user by the Red Hat Certificate System. Once the
CoolKey is provisioned, the user can take the key to any system and use
it to login (authenticate), send and receive signed and encrypted
email, or participate in secure messaging or IRC communication. Using a
CoolKey should be as easy as starting a car. To accomplish that vision,
we are focusing on building complete support for CoolKey on exactly one
token. As the system is built out, we can add token support. CoolKeys
are based on JavaCard 1.2. We are testing with Axalto Egate Cyberflex
cards, which are available in both smart card and USB Fob form factors.



%package devel
License:        LGPL-2.1
Summary:        CoolKey and CAC PKCS #11 PKI Module for Smart Cards
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Linux Driver support for the CoolKey and CAC products.

CoolKeys are part of complete PKI solution that provides smart card
login, single sign-on, secure messaging, and secure email access. In
the complete solution, users are issued CoolKeys by their employer,
ISP, bank, or other agency. When the user plugs in the keys for the
first time, the keys are automatically provisioned with certificates,
keys, and a PIN unique to that user by the Red Hat Certificate System.
Once the CoolKey is provisioned, the user can take the key to any
system and use it to login (authenticate), send and receive signed and
encrypted email, or participate in secure messaging or IRC
communication. Using a CoolKey should be as easy as starting a car.

To accomplish that vision we are focusing on building complete support
for CoolKey on exactly one token. As the system is built out, we can
add token support. CoolKeys are based on JavaCard 1.2. We are testing
with Axalto Egate Cyberflex cards, which are available in both smart
card and USB Fob form factors.



%prep
%setup -q
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7
%patch8
%patch53 -p1
%patch54
%patch55

%build
autoreconf -f -i
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure\
	--disable-dependency-tracking \
	--enable-pk11install
make %{?_smp_mflags}

%install
%makeinstall
ln -s pkcs11/libcoolkeypk11.so $RPM_BUILD_ROOT/%{_libdir}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ChangeLog LICENSE README
%{_bindir}/pk11install
%{_libdir}/libcoolkeypk11.so
%{_libdir}/pkcs11/*.so
%{_libdir}/libckyapplet.so.*
# FIXME: Find a common package owning this directory:
%dir %{_libdir}/pkcs11

%files devel
%defattr(-,root,root)
%{_libdir}/libckyapplet.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*.h

%changelog
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Jan 10 2011 sbrabec@suse.cz
- Merged latest Fedora patches (bnc#661643).
* Tue Apr 14 2009 sbrabec@suse.cz
- Fixed wrong C++ delete (bnc#443369, Redhat#485032).
* Mon Oct 29 2007 sbrabec@suse.cz
- Fixed gcc 4.3 build errors.
* Mon Sep 10 2007 sbrabec@suse.cz
- Fixed file and directory permission flaw (#304180,
  CVE-2007-4129).
* Thu Sep  6 2007 jberkman@novell.com
- install pk11install
- teach pk11install about evolution and openoffice
* Fri Aug  3 2007 sbrabec@suse.cz
- New SuSE package, version 1.1.0.
